@@ -10,10 +10,9 @@ This is the complete API reference:
    :toctree: .
 
    readout_type
-   readout_platform
 """
 
-__version__ = "0.0.4"  # denote a pre-release for 0.1.0 with 0.1a1
+__version__ = "0.0.5"  # denote a pre-release for 0.1.0 with 0.1a1
 
 from . import lookup  # noqa
-from ._core import readout_platform, readout_type  # noqa
+from ._efo import EFO, readout_type  # noqa
